@@ -4,25 +4,25 @@ Main interface for mgn service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_mgn import (
         Client,
         DescribeJobLogItemsPaginator,
         DescribeJobsPaginator,
         DescribeReplicationConfigurationTemplatesPaginator,
         DescribeSourceServersPaginator,
+        DescribeVcenterClientsPaginator,
         mgnClient,
     )
 
-    session = boto3.Session()
-
-    client: mgnClient = boto3.client("mgn")
-    session_client: mgnClient = session.client("mgn")
+    session = Session()
+    client: mgnClient = session.client("mgn")
 
     describe_job_log_items_paginator: DescribeJobLogItemsPaginator = client.get_paginator("describe_job_log_items")
     describe_jobs_paginator: DescribeJobsPaginator = client.get_paginator("describe_jobs")
     describe_replication_configuration_templates_paginator: DescribeReplicationConfigurationTemplatesPaginator = client.get_paginator("describe_replication_configuration_templates")
     describe_source_servers_paginator: DescribeSourceServersPaginator = client.get_paginator("describe_source_servers")
+    describe_vcenter_clients_paginator: DescribeVcenterClientsPaginator = client.get_paginator("describe_vcenter_clients")
     ```
 """
 from .client import mgnClient
@@ -31,6 +31,7 @@ from .paginator import (
     DescribeJobsPaginator,
     DescribeReplicationConfigurationTemplatesPaginator,
     DescribeSourceServersPaginator,
+    DescribeVcenterClientsPaginator,
 )
 
 Client = mgnClient
@@ -42,5 +43,6 @@ __all__ = (
     "DescribeJobsPaginator",
     "DescribeReplicationConfigurationTemplatesPaginator",
     "DescribeSourceServersPaginator",
+    "DescribeVcenterClientsPaginator",
     "mgnClient",
 )
