@@ -1,14 +1,14 @@
 """
 Type annotations for mgn service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/literals.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mgn/literals/)
 
 Usage::
 
     ```python
-    from mypy_boto3_mgn.literals import ChangeServerLifeCycleStateSourceServerLifecycleStateType
+    from mypy_boto3_mgn.literals import BootModeType
 
-    data: ChangeServerLifeCycleStateSourceServerLifecycleStateType = "CUTOVER"
+    data: BootModeType = "LEGACY_BIOS"
     ```
 """
 import sys
@@ -20,6 +20,7 @@ else:
 
 
 __all__ = (
+    "BootModeType",
     "ChangeServerLifeCycleStateSourceServerLifecycleStateType",
     "DataReplicationErrorStringType",
     "DataReplicationInitiationStepNameType",
@@ -44,11 +45,15 @@ __all__ = (
     "ReplicationConfigurationReplicatedDiskStagingDiskTypeType",
     "ReplicationTypeType",
     "TargetInstanceTypeRightSizingMethodType",
+    "mgnServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
+    "RegionName",
 )
 
 
+BootModeType = Literal["LEGACY_BIOS", "UEFI"]
 ChangeServerLifeCycleStateSourceServerLifecycleStateType = Literal[
     "CUTOVER", "READY_FOR_CUTOVER", "READY_FOR_TEST"
 ]
@@ -143,13 +148,14 @@ LifeCycleStateType = Literal[
     "TESTING",
 ]
 ReplicationConfigurationDataPlaneRoutingType = Literal["PRIVATE_IP", "PUBLIC_IP"]
-ReplicationConfigurationDefaultLargeStagingDiskTypeType = Literal["GP2", "ST1"]
+ReplicationConfigurationDefaultLargeStagingDiskTypeType = Literal["GP2", "GP3", "ST1"]
 ReplicationConfigurationEbsEncryptionType = Literal["CUSTOM", "DEFAULT"]
 ReplicationConfigurationReplicatedDiskStagingDiskTypeType = Literal[
-    "AUTO", "GP2", "IO1", "SC1", "ST1", "STANDARD"
+    "AUTO", "GP2", "GP3", "IO1", "IO2", "SC1", "ST1", "STANDARD"
 ]
 ReplicationTypeType = Literal["AGENT_BASED", "SNAPSHOT_SHIPPING"]
 TargetInstanceTypeRightSizingMethodType = Literal["BASIC", "NONE"]
+mgnServiceName = Literal["mgn"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -181,11 +187,13 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
     "chime",
     "chime-sdk-identity",
+    "chime-sdk-media-pipelines",
     "chime-sdk-meetings",
     "chime-sdk-messaging",
     "cloud9",
@@ -267,6 +275,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -300,9 +309,11 @@ ServiceName = Literal[
     "iottwinmaker",
     "iotwireless",
     "ivs",
+    "ivschat",
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -367,6 +378,7 @@ ServiceName = Literal[
     "pinpoint",
     "pinpoint-email",
     "pinpoint-sms-voice",
+    "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
     "proton",
@@ -451,6 +463,18 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal[
     "describe_job_log_items",
     "describe_jobs",
@@ -458,3 +482,26 @@ PaginatorName = Literal[
     "describe_source_servers",
     "describe_vcenter_clients",
 ]
+RegionName = Literal[
+    "af-south-1",
+    "ap-east-1",
+    "ap-northeast-1",
+    "ap-northeast-2",
+    "ap-northeast-3",
+    "ap-south-1",
+    "ap-southeast-1",
+    "ap-southeast-2",
+    "ca-central-1",
+    "eu-central-1",
+    "eu-north-1",
+    "eu-south-1",
+    "eu-west-1",
+    "eu-west-2",
+    "eu-west-3",
+    "me-south-1",
+    "sa-east-1",
+    "us-east-1",
+    "us-east-2",
+    "us-west-1",
+    "us-west-2",
+]
